;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "lsp-ui" "20250804.2109"
  "UI modules for lsp-mode."
  '((emacs         "28.1")
    (dash          "2.18.0")
    (lsp-mode      "6.0")
    (markdown-mode "2.3"))
  :url "https://github.com/emacs-lsp/lsp-ui"
  :commit "dcce464bc5d171daebf19009fdfbbc959bf2e7cf"
  :revdesc "dcce464bc5d1"
  :keywords '("languages" "tools")
  :authors '(("Sebastien Chapuis" . "sebastien@chapu.is")
             ("Fangrui Song" . "i@maskray.me"))
  :maintainers '(("Sebastien Chapuis" . "sebastien@chapu.is")
                 ("Fangrui Song" . "i@maskray.me")))
